@@ -46,6 +46,7 @@ from .type_defs import (
     DescribeAccountHealthResponseTypeDef,
     DescribeAccountOverviewResponseTypeDef,
     DescribeAnomalyResponseTypeDef,
+    DescribeEventSourcesConfigResponseTypeDef,
     DescribeFeedbackResponseTypeDef,
     DescribeInsightResponseTypeDef,
     DescribeOrganizationHealthResponseTypeDef,
@@ -53,6 +54,7 @@ from .type_defs import (
     DescribeOrganizationResourceCollectionHealthResponseTypeDef,
     DescribeResourceCollectionHealthResponseTypeDef,
     DescribeServiceIntegrationResponseTypeDef,
+    EventSourcesConfigTypeDef,
     GetCostEstimationResponseTypeDef,
     GetResourceCollectionResponseTypeDef,
     InsightFeedbackTypeDef,
@@ -167,6 +169,15 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_anomaly)
         """
 
+    def describe_event_sources_config(self) -> DescribeEventSourcesConfigResponseTypeDef:
+        """
+        This operation lists details about a DevOps Guru event source that is shared
+        with your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.describe_event_sources_config)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_event_sources_config)
+        """
+
     def describe_feedback(self, *, InsightId: str = ...) -> DescribeFeedbackResponseTypeDef:
         """
         Returns the most recent feedback submitted in the current Amazon Web Services
@@ -432,6 +443,16 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#start_cost_estimation)
         """
 
+    def update_event_sources_config(
+        self, *, EventSources: "EventSourcesConfigTypeDef" = ...
+    ) -> Dict[str, Any]:
+        """
+        Updates the event source configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.update_event_sources_config)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#update_event_sources_config)
+        """
+
     def update_resource_collection(
         self,
         *,
