@@ -31,6 +31,7 @@ __all__ = (
     "DescribeResourceCollectionHealthPaginatorName",
     "EventClassType",
     "EventDataSourceType",
+    "EventSourceOptInStatusType",
     "GetCostEstimationPaginatorName",
     "GetResourceCollectionPaginatorName",
     "InsightFeedbackOptionType",
@@ -51,7 +52,9 @@ __all__ = (
     "SearchOrganizationInsightsPaginatorName",
     "ServiceNameType",
     "UpdateResourceCollectionActionType",
+    "DevOpsGuruServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -73,6 +76,7 @@ EventClassType = Literal[
     "CONFIG_CHANGE", "DEPLOYMENT", "INFRASTRUCTURE", "SCHEMA_CHANGE", "SECURITY_CHANGE"
 ]
 EventDataSourceType = Literal["AWS_CLOUD_TRAIL", "AWS_CODE_DEPLOY"]
+EventSourceOptInStatusType = Literal["DISABLED", "ENABLED"]
 GetCostEstimationPaginatorName = Literal["get_cost_estimation"]
 GetResourceCollectionPaginatorName = Literal["get_resource_collection"]
 InsightFeedbackOptionType = Literal[
@@ -139,6 +143,7 @@ ServiceNameType = Literal[
     "SWF",
 ]
 UpdateResourceCollectionActionType = Literal["ADD", "REMOVE"]
+DevOpsGuruServiceName = Literal["devops-guru"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -170,6 +175,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -292,6 +298,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -440,6 +447,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_organization_resource_collection_health",
     "describe_resource_collection_health",
